Mvcapa
===============================================

.. currentmodule:: skchange.anomaly_detectors

.. autoclass:: Mvcapa

.. include:: skchange.anomaly_detectors.Mvcapa.examples

.. raw:: html

    <div class="clearer"></div>